---
hide:
  - navigation
  - toc
---

!!! new "This sandbox is powered by [Pyodide](https://github.com/pyodide/pyodide). Preview, convert, interpolate, and explore!"

<div id="playground-results">
<div class="color-command">
<div class="swatch-bar"></div>
<div class="highlight"><pre><code>Loading coloraide...</code></pre></div>
</div>
</div>
<div id="playground-code" class="hidden">
<div class="highlight"><pre><code></code></pre></div>
<form autocomplete="off">
<textarea id="playground-inputs" spellcheck="false"></textarea>
</form>
</div>

<button id="playground-edit" title="Ctrl + Enter">:material-pencil: Edit</button>
<button id="playground-share" title="Copy URL to current snippet">:material-monitor-share: Share</button>
<button id="playground-run" class="hidden" title="Ctrl + Enter">:material-console: Run</button>
<button id="playground-cancel" class="hidden" title="Escape">:material-cancel: Cancel</button>

--8<-- "playground.txt"
